@@ -1,9 +1,9 @@
 package Acme::CPANModules::CLI::Wrapper::UnixCommand;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-08-26'; # DATE
+our $DATE = '2020-10-27'; # DATE
 our $DIST = 'Acme-CPANModules-CLI-Wrapper-UnixCommand'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 our $LIST = {
     summary => "Various CLIs that wrap (popular) Unix commands",
@@ -65,6 +65,12 @@ _
             script => ['diff-doc-text'],
             'x.command' => 'diff',
         },
+        {
+            summary => 'Diffs two office spreadsheets by first converting them to directories of CSV files',
+            module => 'App::DiffXlsText',
+            script => ['diff-xls-text'],
+            'x.command' => 'diff',
+        },
         {
             summary => 'Provides sdif (diff side-by-side with nice color theme), cdif (highlight words with nice color scheme), and watchdiff (watch command and diff output)',
             module => 'App::sdif',
@@ -96,7 +102,7 @@ Acme::CPANModules::CLI::Wrapper::UnixCommand - Various CLIs that wrap (popular)
 
 =head1 VERSION
 
-This document describes version 0.003 of Acme::CPANModules::CLI::Wrapper::UnixCommand (from Perl distribution Acme-CPANModules-CLI-Wrapper-UnixCommand), released on 2020-08-26.
+This document describes version 0.004 of Acme::CPANModules::CLI::Wrapper::UnixCommand (from Perl distribution Acme-CPANModules-CLI-Wrapper-UnixCommand), released on 2020-10-27.
 
 =head1 DESCRIPTION
 
@@ -108,7 +114,7 @@ But they perform additional stuff.
 
 If you know of others, please drop me a message.
 
-=head1 INCLUDED MODULES
+=head1 MODULES INCLUDED IN THIS ACME::CPANMODULE MODULE
 
 =over
 
@@ -126,6 +132,8 @@ If you know of others, please drop me a message.
 
 =item * L<App::DiffDocText> - Diffs two office word-processor documents by first converting them to plaintext
 
+=item * L<App::DiffXlsText> - Diffs two office spreadsheets by first converting them to directories of CSV files
+
 =item * L<App::sdif> - Provides sdif (diff side-by-side with nice color theme), cdif (highlight words with nice color scheme), and watchdiff (watch command and diff output)
 
 =item * L<App::lcpan> - Wraps cpanm to use local CPAN mirror and let you specify script name to install instead of module name
@@ -177,7 +185,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
